==> taboola_sdk-0.3.1.tar.gz: lib/native_plugin/taboola_sdk_plugin.dart <==
import 'package:flutter/services.dart';
import 'package:taboola_sdk/utils/logger.dart';

/// This class is the Dart part of a 2-way bridge to native Android & iOS code.
///
/// The mirroring part is:
///   - In Android /taboola_sdk/android/src.main/java.com.taboola.flutter/TaboolaSdkPlugin.java
///     -- Editing this plugin is best done when editing /taboola_sdk/android/ in AndroidStudio and enabling a Gradle dependency on the Flutter.jar placed in libs.
///     -- Add your new method to the onMethodCall() filter function
///     -- After you finish editing in Android Studio, disable the Gradle dependency of Flutter.jar
///
///   - In iOS /taboola_sdk/ios/Classes/SwiftTaboolaSdkPlugin.swift
///     -- Add your new method to the handle() filter function
///
///Source: https://flutter.dev/docs/development/platform-integration/platform-channels
class TaboolaSdkPlugin {

  static const String IS_USER_OPT_OUT = "isUserOptOut";
  static const String TABOOLA_SDK_CHANNEL = "taboola_sdk";
  static const String GET_AD_OR_IDFA = "getAdIdOrIdfa";
  static const String GET_ISO_COUNTRY_CODE = "getIsoCountryCode";

  static const _nativeChannel = const MethodChannel(TABOOLA_SDK_CHANNEL);

  static Future<bool> isUserOptOut() async {
    final bool isUserOptOut = await _nativeChannel.invokeMethod(IS_USER_OPT_OUT);
    Logger.log('TabooalaNative | isUserOptOut = $isUserOptOut');
    return isUserOptOut;
  }

  /// By definition, Android plugin will always return advId, iOS plugin will return an empty String if user has opted out.
  static Future<String> getAdIdOrIdfa() async {
    final String getAdIdOrIdfa = await _nativeChannel.invokeMethod(GET_AD_OR_IDFA);
    Logger.log('TabooalaNative | getAdIdOrIdfa = $getAdIdOrIdfa');
    return getAdIdOrIdfa;
  }

  static Future<String> getIsoCountryCode() async {
    final String getIsoCountryCode = await _nativeChannel.invokeMethod(GET_ISO_COUNTRY_CODE);
    Logger.log('TabooalaNative | getIsoCountryCode = $getIsoCountryCode');
    return getIsoCountryCode;
  }

}

==> taboola_sdk-0.3.3.tar.gz: lib/native_plugin/taboola_sdk_plugin.dart <==
import 'dart:convert';

import 'package:flutter/services.dart';
import 'package:taboola_sdk/native_plugin/taboola_package_info_data.dart';
import 'package:taboola_sdk/native_plugin/taboola_package_info_platform_interface.dart';
import 'package:taboola_sdk/utils/logger.dart';

/// This class is the Dart part of a 2-way bridge to native Android & iOS code.
///
/// The mirroring part is:
///   - In Android /taboola_sdk/android/src.main/java.com.taboola.flutter/TaboolaSdkPlugin.java
///     -- Editing this plugin is best done when editing /taboola_sdk/android/ in AndroidStudio and enabling a Gradle dependency on the Flutter.jar placed in libs.
///     -- Add your new method to the onMethodCall() filter function
///     -- After you finish editing in Android Studio, disable the Gradle dependency of Flutter.jar
///
///   - In iOS /taboola_sdk/ios/Classes/SwiftTaboolaSdkPlugin.swift
///     -- Add your new method to the handle() filter function
///
///Source: https://flutter.dev/docs/development/platform-integration/platform-channels
class TaboolaSdkPlugin extends TaboolaPackageInfoPlatform {

  static const String IS_USER_OPT_OUT = "isUserOptOut";
  static const String TABOOLA_SDK_CHANNEL = "taboola_sdk";
  static const String GET_AD_OR_IDFA = "getAdIdOrIdfa";
  static const String GET_ISO_COUNTRY_CODE = "getIsoCountryCode";
  static const String GET_ALL_APPLICATION_INFO = "getAllPackageInfo";

  static const _nativeChannel = const MethodChannel(TABOOLA_SDK_CHANNEL);

  static Future<bool> isUserOptOut() async {
    final bool isUserOptOut = await _nativeChannel.invokeMethod(IS_USER_OPT_OUT);
    Logger.log('TabooalaNative | isUserOptOut = $isUserOptOut');
    return isUserOptOut;
  }

  /// By definition, Android plugin will always return advId, iOS plugin will return an empty String if user has opted out.
  static Future<String> getAdIdOrIdfa() async {
    final String getAdIdOrIdfa = await _nativeChannel.invokeMethod(GET_AD_OR_IDFA);
    Logger.log('TabooalaNative | getAdIdOrIdfa = $getAdIdOrIdfa');
    return getAdIdOrIdfa;
  }

  static Future<String> getIsoCountryCode() async {
    final String getIsoCountryCode = await _nativeChannel.invokeMethod(GET_ISO_COUNTRY_CODE);
    Logger.log('TabooalaNative | getIsoCountryCode = $getIsoCountryCode');
    return getIsoCountryCode;
  }
  Future<TaboolaPackageInfoData> getAllPackageInfo() async {
    final map = await _nativeChannel.invokeMapMethod<String, dynamic>(GET_ALL_APPLICATION_INFO);
    String jsonString = json.encode(map);

    Logger.log('TabooalaNative | getAllDeviceInfo = $jsonString');

    return TaboolaPackageInfoData(
      appName: map!['appName'] ?? '',
      packageName: map['packageName'] ?? '',
      version: map['version'] ?? '',
    );
  }

}
